@@ -92,6 +92,10 @@ def main() :
 
         else : 
             words = response['words']
+
+            if not words : 
+                print("No words in the trie.")
+
             for word in words : 
                 print(word)
     
@@ -108,7 +112,11 @@ def main() :
 
             if response == erroneous_message : print("Unable to perform this operation.")
             else : 
-                print(response['suggestions'])
+
+                if not response['suggestions'] : 
+                    print("No suggestions for this prefix.")
+                else :     
+                    print(response['suggestions'])
 
     else : 
         print(f"No known action : {action}")
